==> isis-fish-3.3.0.5-sources.jar: fr/ifremer/isisfish/util/DateConverter.java <==
/* *##%
 * Copyright (C) 2006
 *     Code Lutin, Cédric Pineau, Benjamin Poussin
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *##%*/

/* *
 * DateConverter.java
 *
 * Created: 13 janv. 2006 01:13:41
 *
 * @author poussin
 * @version $Revision: 1526 $
 *
 * Last update: $Date: 2008-10-07 18:46:13 +0200 (mar., 07 oct. 2008) $
 * by : $Author: tchemit $
 */

package fr.ifremer.isisfish.util;

import org.apache.commons.beanutils.ConversionException;
import org.apache.commons.beanutils.Converter;

import fr.ifremer.isisfish.types.Date;


/**
 * Classe utilise pour convertir une chaine en un objet Date.
 * Utilisé pour la conversion et le stockage en propriete des parametres
 * @author poussin
 *
 */
public class DateConverter implements Converter {

    /* (non-Javadoc)
     * @see org.apache.commons.beanutils.Converter#convert(java.lang.Class, java.lang.Object)
     */
    public Object convert(Class type, Object value) {
        Object result;
        if (value instanceof Date) {
            result = value;
        } else if (value instanceof String) {
            int d = Integer.parseInt(value.toString());
            result = new Date(d);
        } else if (value == null) {
            result = new Date(0);
        } else {
            throw new ConversionException("Can't convert '" + value + "' to " + type.getName());
        }
        return result;
    }

}

==> isis-fish-3.3.0.6-sources.jar: fr/ifremer/isisfish/util/DateConverter.java <==
/*
 * #%L
 * IsisFish
 * 
 * $Id: DateConverter.java 3124 2010-11-29 18:14:09Z chatellier $
 * $HeadURL$
 * %%
 * Copyright (C) 2006 - 2010 Ifremer, Code Lutin, Cédric Pineau, Benjamin Poussin
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 2 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-2.0.html>.
 * #L%
 */

package fr.ifremer.isisfish.util;

import org.apache.commons.beanutils.ConversionException;
import org.apache.commons.beanutils.Converter;

import fr.ifremer.isisfish.types.Date;


/**
 * Classe utilise pour convertir une chaine en un objet Date.
 * 
 * Utilisé pour la conversion et le stockage en propriete des parametres.
 * 
 * @author poussin
 */
public class DateConverter implements Converter {

    /* (non-Javadoc)
     * @see org.apache.commons.beanutils.Converter#convert(java.lang.Class, java.lang.Object)
     */
    public Object convert(Class type, Object value) {
        Object result;
        if (value instanceof Date) {
            result = value;
        } else if (value instanceof String) {
            int d = Integer.parseInt(value.toString());
            result = new Date(d);
        } else if (value == null) {
            result = new Date(0);
        } else {
            throw new ConversionException("Can't convert '" + value + "' to " + type.getName());
        }
        return result;
    }

}
